<?php

namespace Drupal\e3_marketo\Entity\Form;

use Drupal\Core\Entity\ContentEntityDeleteForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a form for deleting Marketo form entity entities.
 *
 * @ingroup e3_marketo
 */
class MarketoFormEntityDeleteForm extends ContentEntityDeleteForm {

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
    $entity = $this->getEntity();
    $message = $this->getDeletionMessage();

    // Make sure that deleting a translation does not delete the whole entity.
    if (!$entity->isDefaultTranslation()) {
      $untranslated_entity = $entity->getUntranslated();
      $untranslated_entity->removeTranslation($entity->language()->getId());
      $untranslated_entity->save();
    }
    else {
      $entity->delete();
    }

    $form_state->setRedirect('view.marketo_forms.marketo_forms_list');
    $this->messenger()->addStatus($message);
    $this->logDeletionMessage();
  }

}
